'''
Created on 5 Jun 2020

@author: jacklok
'''


from mailjet_rest import Client
from six import string_types
import logging
from trexmail import conf

api_key         = None#conf.MAILJET_API_KEY
api_secret      = None#conf.MAILJET_SECRET_KEY

def send_email(sender=None, to_address=None, cc_address=None, bcc_address=None, subject=None, 
               body=None, html=None, batch_id=None, app=None):
    
    logging.info('sender=%s', sender)
    logging.info('to_address=%s', to_address)
    logging.info('subject=%s', subject)
    
    logging.info('api_key=%s', api_key)
    logging.info('api_secret=%s', api_secret)
    
    
    mailjet = Client(auth=(api_key, api_secret), version='v3.1')
    
    to_address_list = None
    
    if isinstance(to_address, string_types):
        to_address_list = [{"Email": to_address}]
    elif isinstance(to_address, (tuple, list)):
        to_address_list = []
        for t in to_address:
            to_address_list.append({"Email": t})
    
    cc_address_list = None
    if isinstance(cc_address, string_types):
        cc_address_list = [{"Email": cc_address}]
    elif isinstance(cc_address, (tuple, list)):
        cc_address_list = []
        for t in cc_address:
            cc_address_list.append({"Email": t})        
            
    bcc_address_list = None
    if isinstance(bcc_address, string_types):
        bcc_address_list = [{"Email": bcc_address}]
    elif isinstance(bcc_address, (tuple, list)):
        bcc_address_list = []
        for t in bcc_address:
            bcc_address_list.append({"Email": t})        
    
    data = {
      'Messages': [
        {
          "From": {
            "Email": sender,
            #"Name": ""
          },
          "To": to_address_list,
          "Bcc": bcc_address_list,
          "Cc": cc_address_list,
          "Subject"     : subject,
          "TextPart"    : body,
          "HTMLPart"    : html,
          "CustomID"    : batch_id
        }
      ]
    }
    result = mailjet.send.create(data=data)
    result_in_json = result.json()
    
    logging.debug('result_in_json=%s', result_in_json)
    logging.debug('result_in_json.Messages=%s', result_in_json.get('Messages'))
    
    response_status = {}
    
    for a in result_in_json.get('Messages')[0].get('To'):
        response_status[a.get('Email')] = {
                                            'message_id'    : a.get('MessageID'),
                                            'message_uuid'  : a.get('MessageUUID'),
                                            }
        
    
    #logging.debug('Status=%s', result.status)
    logging.debug('Result=%s', result_in_json)
    
    return result_in_json.get('Messages')[0].get('Status')=='success'
    





'''
Created on 15 Jul 2022

@author: jacklok
'''
from trexlib.utils.google.cloud_tasks_util import create_task 
import logging
from trexmail.flask_mail import send_email
from flask import current_app
from trexlib.conf import SEND_EMAIL_TASK_URL
from trexlib.conf import DEPLOYMENT_MODE, LOCAL_MODE, SYSTEM_TASK_SERVICE_CREDENTIAL_PATH, SYSTEM_TASK_GCLOUD_PROJECT_ID, SYSTEM_TASK_GCLOUD_LOCATION, SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL 
from trexmail.conf import DEFAULT_SENDER

logger = logging.getLogger('helper')
#logger = logging.getLogger('debug')

def trigger_send_email(sender_address=DEFAULT_SENDER, recipient_address=None, subject=None, message=None, cc_address=None):
    
    logger.debug('sender_address=%s', sender_address)
    logger.debug('recipient_address=%s', recipient_address)
    '''
    send_email(sender           = sender_address, 
                   to_address   = [recipient_address], 
                   subject      = subject, 
                   body         = message,
                   app          = current_app
                   )
    
    '''
    #if DEPLOYMENT_MODE == LOCAL_MODE:
    if False:
        logger.info('send email directly')
        send_email(sender           = sender_address, 
                   to_address   = [recipient_address], 
                   subject      = subject, 
                   body         = message,
                   app          = current_app
                   )
    
    else:
        logger.info('send email to task queue')
        queue_name      = 'send-email' 
        payload         = {
                                'sender_address'    : sender_address,
                                'recipient_address' : recipient_address,
                                'subject'           : subject,
                                'message'           : message,
                                'cc_address'        : cc_address,
                            }
        logger.info('payload=%s', payload)
                        
        create_task(SEND_EMAIL_TASK_URL, queue_name, payload=payload, 
                        in_seconds      = 1, 
                        http_method     = 'POST',
                        credential_path = SYSTEM_TASK_SERVICE_CREDENTIAL_PATH, 
                        project_id      = SYSTEM_TASK_GCLOUD_PROJECT_ID,
                        location        = SYSTEM_TASK_GCLOUD_LOCATION,
                        service_email   = SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL
                        )
     
    return True



'''
Created on 4 Jun 2020

@author: jacklok
'''

from flask_mail import Mail, Message 
import logging

def send_email(sender=None, to_address=None, cc_address=None, bcc_address=None, subject=None, 
               body=None, html=None, batch_id=None, is_html=False, app=None):
    
    logging.info('to_address=%s', to_address)
    logging.info('sender=%s', sender)
        
    msg = Message(subject, sender=sender, recipients=to_address, cc=cc_address, bcc=bcc_address)
    if is_html:
        msg.html = html
    else:
        msg.body = body
    
    mail = Mail(app=app)
    
    logging.info('mail.username=%s', mail.username)
    logging.info('mail.password=%s', mail.password)
        
    mail.send(msg)
    
    return True